package cl.axg.hls_player;

import android.annotation.SuppressLint;
import android.content.Context;
import android.graphics.Color;
import android.net.Uri;
import android.os.Handler;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.ImageView;
import android.widget.LinearLayout;

import com.google.android.exoplayer2.DefaultRenderersFactory;
import com.google.android.exoplayer2.Player;
import com.google.android.exoplayer2.SimpleExoPlayer;
import com.google.android.exoplayer2.ext.rtmp.RtmpDataSourceFactory;
import com.google.android.exoplayer2.source.ExtractorMediaSource;
import com.google.android.exoplayer2.source.MediaSource;
import com.google.android.exoplayer2.source.ProgressiveMediaSource;
import com.google.android.exoplayer2.source.dash.DashMediaSource;
import com.google.android.exoplayer2.source.hls.HlsMediaSource;
import com.google.android.exoplayer2.trackselection.DefaultTrackSelector;
import com.google.android.exoplayer2.ui.PlayerView;
import com.google.android.exoplayer2.upstream.DefaultHttpDataSource;
import com.google.android.exoplayer2.upstream.DefaultHttpDataSourceFactory;
import com.google.android.exoplayer2.util.Util;

import java.security.SecureRandom;
import java.security.cert.X509Certificate;
import java.util.Objects;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSession;
import javax.net.ssl.TrustManager;
import javax.net.ssl.X509TrustManager;

public class Common {
    Handler mHandler = new Handler();

    public SimpleExoPlayer initPlayer(Context context, PlayerView playerView){
        playerView.requestFocus();
        if(mHandler!=null)
            mHandler.removeMessages(0);
        DefaultTrackSelector trackSelector = new DefaultTrackSelector(context);
        trackSelector.setParameters(trackSelector.buildUponParameters()
                .setMaxAudioChannelCount(1)
        );

        SimpleExoPlayer player = new SimpleExoPlayer.Builder(context, habilitarFFMPEG(context)).setTrackSelector(trackSelector).build();
        playerView.setPlayer(player);
        playerView.setShowBuffering(PlayerView.SHOW_BUFFERING_ALWAYS);
       return player;
    }

    public void habilitarVentanaEncendida(Window windows){
        windows.addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON);
    }

    public  void  habilitarPreferenciasReproductor(Window windows){
        windows.getDecorView().setSystemUiVisibility(
                View.SYSTEM_UI_FLAG_LAYOUT_STABLE
                        | View.SYSTEM_UI_FLAG_LAYOUT_HIDE_NAVIGATION
                        | View.SYSTEM_UI_FLAG_LAYOUT_FULLSCREEN
                        | View.SYSTEM_UI_FLAG_HIDE_NAVIGATION
                        | View.SYSTEM_UI_FLAG_FULLSCREEN
                        | View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY);
    }
    
    private  DefaultRenderersFactory habilitarFFMPEG(Context ctx){

        //inicio definicio - habilitar codec AC3 FFMPEG
        DefaultRenderersFactory factory = new DefaultRenderersFactory(ctx);
        factory.setExtensionRendererMode(DefaultRenderersFactory.EXTENSION_RENDERER_MODE_PREFER);
        //fin definicio - habilitar codec AC3 FFMPEG
    return factory;
    }

    public  MediaSource getMediaSource(Uri uri, Context context){
        DefaultHttpDataSourceFactory dataSourceFactory = new DefaultHttpDataSourceFactory(
                Util.getUserAgent(context, "VideoPlayerGlue"),
                DefaultHttpDataSource.DEFAULT_CONNECT_TIMEOUT_MILLIS,
                DefaultHttpDataSource.DEFAULT_READ_TIMEOUT_MILLIS,
                true);
        String[] extension = Objects.requireNonNull(uri.getPath()).split("\\.");
        int largo = extension.length;
        if(largo>1){
            switch (extension[largo-1].toUpperCase()){
                case "MPD":
                    return new DashMediaSource
                            .Factory(dataSourceFactory)
                            .createMediaSource(uri);
                case "M3U8":
                    return new HlsMediaSource
                            .Factory(dataSourceFactory)
                            .createMediaSource(uri);
            }
        }else{
            if (uri.toString().startsWith("rtmp"))
            {
                return new ExtractorMediaSource
                        .Factory(new RtmpDataSourceFactory())
                        .createMediaSource(uri);
            }
        }

        return new ProgressiveMediaSource.Factory(dataSourceFactory).
                createMediaSource(uri);
    }

}
